@@ -1,16 +1,7 @@
 `clt.ani` <-
 function(n = 30, FUN = runif, control = ani.control(interval = 0.1), 
     ...) {
-    extraArgs = list(...)
-    if (length(extraArgs)) {
-        controlargs = names(formals(ani.control))
-        idx = match(names(extraArgs), controlargs, nomatch = 0)
-        if (any(idx == 0)) 
-            stop("Argument ", names(extraArgs)[idx == 0], "not matched")
-        control[names(extraArgs)] = extraArgs
-        if ("interval" %in% names(extraArgs)) 
-            ani.control(...)
-    }
+    control = checkargs(control, ...) 
     op = par(mar = c(3, 3, 2, 0.5), mgp = c(1.5, 0.5, 0), tcl = -0.3)
     layout(matrix(c(1, 3, 2, 3), 2))
     x = FUN(n)
@@ -28,7 +19,7 @@ function(n = 30, FUN = runif, control = ani.control(interval = 0.1),
         lines(density(xbar), col = "red")
         if (control$saveANI) 
             savePNG(n = i, width = control$width, height = control$height)
-        Sys.sleep(control$interval)
+        else Sys.sleep(control$interval)
     }
     par(op)
     invisible(NULL)
