@@ -1,15 +1,6 @@
 cv.ani <- function(x = runif(150), k = 10, control = ani.control(interval = 2, 
     nmax = 50), ...) {
-    extraArgs = list(...)
-    if (length(extraArgs)) {
-        controlargs = names(formals(ani.control))
-        idx = match(names(extraArgs), controlargs, nomatch = 0)
-        if (any(idx == 0)) 
-            stop("Argument ", names(extraArgs)[idx == 0], "not matched")
-        control[names(extraArgs)] = extraArgs
-        if ("interval" %in% names(extraArgs)) 
-            ani.control(...)
-    }
+    control = checkargs(control, ...) 
     N = length(x)
     n = sample(N)
     x = x[n]
@@ -39,7 +30,7 @@ cv.ani <- function(x = runif(150), k = 10, control = ani.control(interval = 2,
             cex = 1.5, col = "blue")
         if (control$saveANI) 
             savePNG(n = j, width = control$width, height = control$height)
-        Sys.sleep(control$interval)
+        else Sys.sleep(control$interval)
         j = j + 1
     }
     invisible(NULL)
