@@ -2,16 +2,7 @@
 function(pop = ceiling(10 * runif(10, 
     0.2, 1)), size = 3, control = ani.control(interval = 0.2), 
     ...) {
-    extraArgs = list(...)
-    if (length(extraArgs)) {
-        controlargs = names(formals(ani.control))
-        idx = match(names(extraArgs), controlargs, nomatch = 0)
-        if (any(idx == 0)) 
-            stop("Argument ", names(extraArgs)[idx == 0], "not matched")
-        control[names(extraArgs)] = extraArgs
-        if ("interval" %in% names(extraArgs)) 
-            ani.control(...)
-    }
+    control = checkargs(control, ...) 
     if (size > length(pop)) 
         stop("sample size must be smaller than the number of clusters")
     ncol = max(pop)
@@ -32,7 +23,7 @@ function(pop = ceiling(10 * runif(10,
         }
         if (control$saveANI) 
             savePNG(n = i, width = control$width, height = control$height)
-        Sys.sleep(control$interval)
+        else Sys.sleep(control$interval)
     }
     par(op)
     invisible(NULL)
